@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11745 2019-10-09 02:24:16Z Lavender $
+# $Id: __init__.py 11770 2019-11-01 05:29:22Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2019-10-09 11:24:16 +0900 (週三, 09 十月 2019) $
-# $Revision: 11745 $
+# $Author: Andy $ (last)
+# $Date: 2019-11-01 13:29:22 +0800 (週五, 01 十一月 2019) $
+# $Revision: 11770 $
 
 from __future__ import print_function
 
@@ -697,8 +697,10 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'django.contrib.sessions',
             'django.contrib.messages',
             'django.contrib.staticfiles',
+            'des',
             'Iuppiter.extension',
             'Iuppiter.i18n',
+            'Iuno.deploy',
             'Iuno.member',
         ),
         MIDDLEWARE: (
@@ -792,6 +794,22 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             warnPackageDisable('Iuno.cloud', settingsDict, iunoCloudDefaults)
     #=========================================================================
     
+    #=========================================================================
+    #ANDY
+    # Iuno.deploy.   
+    try:
+        checkImportPackage('Iuno.deploy', settingsDict)
+    except ImportError:
+        pass
+    else:
+        import Iuno.deploy
+    
+    require('IUNO_SITE_DOMAIN_NAMES', settingsDict)
+    allowedHosts = Iuno.deploy.attachSettings(settingsDict, 
+        settingsDict['IUNO_SITE_DOMAIN_NAMES'])   #沒設要required
+    # update(settingsDict, {ALLOWED_HOSTS: allowedHosts})
+    #=========================================================================
+ 
     #=========================================================================
     # Iuno.member.
     try:
