@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # $Id: start_app.py 11244 2018-10-10 15:19:58Z Lavender $
 #
-# Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -106,4 +106,30 @@ class Command(BaseCommand):
                    
                         result = func()
             except Exception as e:
-                continue
\ No newline at end of file
+                continue
+                
+def attachSettings(settingsDict, iunoSiteDomainNames=None):
+    """
+    Attach default settings to settings.py.
+    It must be called in settings by passing locals().
+
+    @param settingsDict locals() in settings.py.
+    @param allowedHosts if have IUNO_SITE_DOMAIN_NAMES
+    """
+    # Andy 
+    # add ALLOWED_HOSTS by IUNO_SITE_DOMAIN_NAMES while in STAGE/PRODUCTION
+    try:       
+        siteNames = iunoSiteDomainNames
+        
+        
+        siteName = siteNames[settingsDict['SERVER_MODE']].replace("www", "")
+        if not siteName.startswith(".") and not siteName.startswith("127.0.0.1"):
+            siteName = ".%s" % siteName
+        settingsDict['ALLOWED_HOSTS'] += [
+            siteName,
+        ]
+        
+       
+    except Exception as e:
+        logger.error(str(e))        
+    #######
\ No newline at end of file
