@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11758 2019-10-22 08:06:50Z Lavender $
+# $Id: forms.py 11768 2019-10-29 10:33:15Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-22 17:06:50 +0900 (週二, 22 十月 2019) $
-# $Revision: 11758 $
+# $Date: 2019-10-29 18:33:15 +0800 (週二, 29 十月 2019) $
+# $Revision: 11768 $
 
 import os
+import re
 import hashlib
 import datetime
 
@@ -34,6 +35,8 @@ from oscar.forms.widgets import DatePickerInput
 from oscar.core.utils import datetime_combine
 from ckeditor_uploader.widgets import CKEditorUploadingWidget
 
+from Iuno.shop.models import OrdererAddress
+
 (RelatedFieldWidgetWrapper,
  ) = get_classes(
     'dashboard.widgets',
@@ -221,6 +224,101 @@ catalogueViews.AttributeOptionGroupCreateUpdateView.form_valid = \
 catalogueViews.AttributeOptionGroupCreateUpdateView.form_invalid = \
     process_all_forms
     
+# oderer address form
+_ShippingAddressForm = get_class(
+    'checkout.forms', 'ShippingAddressForm')
+Country = get_model('address', 'Country')
+    
+class ShippingAddressForm2(_ShippingAddressForm):
+    odererFirstName = forms.CharField(
+        label=_('Orderer first name'), required=True)
+    odererLastName = forms.CharField(
+        label=_('Orderer last name'), required=True)
+    odererLine1 = forms.CharField(
+        label=_('Orderer first line of address'), required=True)
+    odererLine4 = forms.CharField(
+        label=_('Orderer city'), required=True)
+    odererCountry = forms.ModelChoiceField(
+        label=_('Orderer country'),
+        queryset=Country.objects.all(), required=True,
+    )
+    odererPostcode = forms.CharField(
+        label=_('Orderer postcode'), required=True)
+        
+    class Meta(_ShippingAddressForm.Meta):
+        fields = [
+            'odererFirstName', 'odererLastName', 'odererLine1', 
+            'odererLine4', 'odererCountry', 'odererPostcode',
+        ] + _ShippingAddressForm.Meta.fields
+  
+    def clean_odererPostcode(self):
+        data = self.cleaned_data['odererPostcode']
+        odererCountry = self.cleaned_data['odererCountry']
+        
+        if (not data 
+            and self.Meta.model.POSTCODE_REQUIRED and odererCountry):
+            countryCode = odererCountry.iso_3166_1_a2
+            regex = self.Meta.model.POSTCODES_REGEX.get(countryCode, None)
+            if regex:
+                msg = _("Addresses in %(country)s require a valid postcode") \
+                    % {'country': self.country}
+                raise exceptions.ValidationError(msg)
+
+        if data and odererCountry:
+            # Ensure postcodes are always uppercase
+            postcode = data.upper().replace(' ', '')
+            countryCode = odererCountry.iso_3166_1_a2
+            regex = self.Meta.model.POSTCODES_REGEX.get(countryCode, None)
+
+            # Validate postcode against regex for the country if available
+            if regex and not re.match(regex, postcode):
+                msg = _("The postcode '%(postcode)s' is not valid "
+                        "for %(country)s") \
+                    % {'postcode': self.postcode,
+                       'country': self.country}
+                raise exceptions.ValidationError(
+                    {'postcode': [msg]})
+                    
+        return data     
+            
+from oscar.apps.checkout import views as checkoutViews
+
+_getForm =  checkoutViews.ShippingAddressView.get_form
+def get_form(self, **kwargs):
+    form = _getForm(self, **kwargs)
+    if (self.request.user.is_authenticated and 
+        not OrdererAddress.objects.filter(user=self.request.user).exists()):
+        return ShippingAddressForm2(**self.get_form_kwargs())
+    return form
+ 
+_getValid =  checkoutViews.ShippingAddressView.form_valid
+UserAddress = get_model('address', 'UserAddress')
+def form_valid(self, form):
+    rt = _getValid(self, form)
+    
+    if (self.request.user.is_authenticated and 
+        not OrdererAddress.objects.filter(user=self.request.user).exists()):
+        address = UserAddress.objects.create(
+            user=self.request.user,
+            first_name=form.cleaned_data['odererFirstName'],
+            last_name=form.cleaned_data['odererLastName'],
+            line1=form.cleaned_data['odererLine1'],
+            line4=form.cleaned_data['odererLine4'],
+            country=form.cleaned_data['odererCountry'],
+            postcode=form.cleaned_data['odererPostcode'],
+        )
+        ordererAddress, created = OrdererAddress.objects.get_or_create(
+            user=self.request.user,
+            defaults={
+                'address': address,
+            }
+        )
+    
+    return rt
+
+checkoutViews.ShippingAddressView.get_form = get_form
+checkoutViews.ShippingAddressView.form_valid = form_valid
+    
 # content block ckeditor
 if not VERSION >= (2, 0, 0):
     # RawHTMLForm
