@@ -3,7 +3,12 @@
 
 
 from django.db import models
+from django.core import exceptions
+from django.contrib.auth import get_user_model
 from django.utils.translation import gettext_lazy as _
+from oscar.core.loading import get_model
+
+UserAddress = get_model('address', 'UserAddress')
 
 TEXT = "text"
 INTEGER = "integer"
@@ -51,6 +56,35 @@ class OptionType(models.Model):
         verbose_name=_("Option Group"),
         help_text=_(
             'Select an option group if using type "Option" or "Multi Option"'))
+            
+class OrdererAddress(models.Model):
+    user = models.ForeignKey(
+        get_user_model(),
+        related_name='orderer',
+        verbose_name=_("Orderer"),
+    )
+    
+    address = models.ForeignKey(
+        'address.UserAddress',
+        on_delete=models.CASCADE,
+        related_name='ordererAddress',
+        verbose_name=_("Orderer Address"),
+    )
+    
+@property
+def isOrdererAddress(self):
+    orderAddress, created = OrdererAddress.objects.get_or_create(
+        user=self.user,
+        defaults={
+            'address': self,
+        }
+    )
+    if orderAddress.address == self:
+        return True
+    else:
+        return False
+        
+UserAddress.isOrdererAddress = isOrdererAddress
 
 class ECPayTrade(models.Model):
     merchantId = models.CharField(max_length=255)
